@@ -1,5 +1,5 @@
 """
-Infrastructure for managing classes with parameters
+Infrastructure for managing classes with parameters.
 
 One aim is to allow easy management of inheritance of parameters.
 
@@ -10,7 +10,7 @@ One aim is to allow easy management of inheritance of parameters.
    DeprecatedParameter
    HideParameter
    Parameterized
-   
+
 .. codeauthor:: David Zwicker <david.zwicker@ds.mpg.de>
 """
 
@@ -258,7 +258,11 @@ class DeprecatedParameter(Parameter):
 
 
 class HideParameter:
-    """a helper class that allows hiding parameters of the parent classes"""
+    """a helper class that allows hiding parameters of the parent classes
+
+    This parameter will still appear in the :attr:`parameters` dictionary, but it will
+    typically not be visible to the user, e.g., when calling :meth:`show_parameters`.
+    """
 
     def __init__(self, name: str):
         """
